@@ -127,9 +127,7 @@ typedef struct GokKeyboard {
 	gboolean bRequiresLayout;
 	gboolean bLaidOut;
 	gboolean bSupportsWordCompletion;
-	gboolean bSupportsCommandPrediction;
 	gboolean bWordCompletionKeysAdded;
-	gboolean bCommandPredictionKeysAdded;
 	GokKeyboardExpandPolicy expand;
 	Accessible* pAccessible;
 	GokSpySearchType search_type;
@@ -159,11 +157,8 @@ gboolean gok_keyboard_add_keys (GokKeyboard* pKeyboard, xmlDoc* pDoc);
 gchar* gok_keyboard_get_name (GokKeyboard* pKeyboard);
 void gok_keyboard_set_name (GokKeyboard* pKeyboard, gchar* Name);
 gboolean gok_keyboard_get_supports_wordcomplete (GokKeyboard* pKeyboard);
-gboolean gok_keyboard_get_supports_commandprediction (GokKeyboard* pKeyboard);
 void gok_keyboard_set_wordcomplete_keys_added (GokKeyboard* pKeyboard, gboolean bTrueFalse);
 gboolean gok_keyboard_get_wordcomplete_keys_added (GokKeyboard* pKeyboard);
-void gok_keyboard_set_commandpredict_keys_added (GokKeyboard* pKeyboard, gboolean bTrueFalse);
-gboolean gok_keyboard_get_commandpredict_keys_added (GokKeyboard* pKeyboard);
 void gok_keyboard_paint_pointer (GokKeyboard *pKeyboard, GtkWidget *pWindowMain, gint x, gint y);
 void gok_keyboard_unpaint_pointer (GokKeyboard *pKeyboard, GtkWidget *pWindowMain);
 gboolean gok_keyboard_display (GokKeyboard* pKeyboard, GokKeyboard* pKeyboardCurrent, GtkWidget* pWindowMain, gboolean CallbackScanner);
