@@ -29,14 +29,14 @@
 #include "gok-word-complete.h"
 #include "gok-log.h"
 
-/* programmer's note: this could do with some more generalization work */
+static gboolean gok_keyslotter_add_wordcomplete_keys (GokKeyboard* pKeyboard);
 
 /**
 * gok_keyslotter_open
 * 
 * Opens and initializes the appropriate engine.
 *
-* returns: TRUE if it was opend OK, FALSE if not.
+* returns: TRUE if it was opened OK, FALSE if not.
 **/
 gboolean
 gok_keyslotter_on (gboolean bOnOff, int keytype)
@@ -51,13 +51,11 @@ gok_keyslotter_on (gboolean bOnOff, int keytype)
 	g_assert (pKeyboard != NULL);
 	while (pKeyboard != NULL)
 	{
-		if (((keytype == KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE)) ||
-		    ((keytype == KEYTYPE_COMMANDPREDICT) && (gok_keyboard_get_supports_commandprediction (pKeyboard) == TRUE)) )
+		if ((keytype == KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE)) 	
 		{
 			if (bOnOff)
 			{
-				if (((keytype == KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == FALSE)) ||
-				    ((keytype == KEYTYPE_COMMANDPREDICT) && (gok_keyboard_get_commandpredict_keys_added (pKeyboard) == FALSE)) )
+				if (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == FALSE) 
 				{
 					/* add the word completion keys to the keyboard */
 					/* first, move all the keys down one row */
@@ -72,20 +70,12 @@ gok_keyslotter_on (gboolean bOnOff, int keytype)
 
 					/* add new slot keys */
 					pKeyboard->NumberRows += 1;
-					if (keytype == KEYTYPE_WORDCOMPLETE)
-					{
-						gok_keyslotter_add_prediction_keys (pKeyboard, keytype);
-					}
-					else if (keytype == KEYTYPE_COMMANDPREDICT)
-					{
-						gok_keyslotter_add_prediction_keys (pKeyboard, keytype);
-					}
+					gok_keyslotter_add_wordcomplete_keys (pKeyboard);
 				}
 			}
 			else /* remove the slot keys from the keyboard */
 			{
-				if (((keytype == KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == TRUE)) ||
-				    ((keytype == KEYTYPE_COMMANDPREDICT) && (gok_keyboard_get_commandpredict_keys_added (pKeyboard) == TRUE)) )
+				if (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == TRUE)
 				{
 					pKey = pKeyboard->pKeyFirst;
 					while (pKey != NULL)
@@ -103,14 +93,7 @@ gok_keyslotter_on (gboolean bOnOff, int keytype)
 						
 						pKey = pKey->pKeyNext;
 					}
-					if (keytype == KEYTYPE_WORDCOMPLETE)
-					{
-						gok_keyboard_set_wordcomplete_keys_added (pKeyboard, FALSE);
-					}
-					else if (keytype == KEYTYPE_COMMANDPREDICT)
-					{
-						gok_keyboard_set_commandpredict_keys_added (pKeyboard, FALSE);
-					}
+					gok_keyboard_set_wordcomplete_keys_added (pKeyboard, FALSE);
 					pKeyboard->NumberRows -= 1;
 				}
 			}
@@ -150,8 +133,7 @@ void gok_keyslotter_change_number_predictions (int Number, int keytype)
 	g_assert (pKeyboard != NULL);
 	while (pKeyboard != NULL)
 	{
-		if ( ((keytype == KEYTYPE_WORDCOMPLETE) &&( gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE)) ||
-		     ((keytype == KEYTYPE_COMMANDPREDICT) &&( gok_keyboard_get_supports_commandprediction (pKeyboard) == TRUE) ))
+		if ((keytype == KEYTYPE_WORDCOMPLETE) &&( gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE))
 		{
 			/* remove all the word completion keys from the keyboard */
 			pKey = pKeyboard->pKeyFirst;
@@ -165,7 +147,7 @@ void gok_keyslotter_change_number_predictions (int Number, int keytype)
 			}
 			
 			/* add new slot keys */
-			gok_keyslotter_add_prediction_keys (pKeyboard, keytype);
+			gok_keyslotter_add_wordcomplete_keys (pKeyboard);
 		}
 		pKeyboard = pKeyboard->pKeyboardNext;
 	}
@@ -173,7 +155,7 @@ void gok_keyslotter_change_number_predictions (int Number, int keytype)
 
 
 /**
-* gok_keyslotter_add_prediction_keys
+* gok_keyslotter_add_wordcomplete_keys
 *
 * @pKeyboard: Pointer to the keyboard that gets the new prediction keys.
 *
@@ -181,10 +163,10 @@ void gok_keyslotter_change_number_predictions (int Number, int keytype)
 *
 * returns: TRUE if the prediction keys were added, FALSE if not.
 **/
-gboolean gok_keyslotter_add_prediction_keys (GokKeyboard* pKeyboard, int keytype)
+static gboolean gok_keyslotter_add_wordcomplete_keys (GokKeyboard* pKeyboard)
 {
 	GokKey* pKeyNew;
-	GokKey* pKeyPrevious;
+	GokKey* pKeyPrevious, *pKeyNext;
 	gint maxcols;
 	gint colperkey;
 	gint colleft;
@@ -194,16 +176,9 @@ gboolean gok_keyslotter_add_prediction_keys (GokKeyboard* pKeyboard, int keytype
 
 	gok_log_enter();
 	
-	/* find the last key in the keyboard's list of keys */
-	/* the prediciton keys get added after this key */
 	pKeyPrevious = pKeyboard->pKeyFirst;
-	if (pKeyPrevious != NULL)
-	{
-		while (pKeyPrevious->pKeyNext != NULL)
-		{
-			pKeyPrevious = pKeyPrevious->pKeyNext;
-		}
-	}
+	if (pKeyPrevious) 
+	    pKeyNext = pKeyPrevious->pKeyNext;
 
 	numPredictions = gok_data_get_num_predictions();
 	maxcols = gok_keyboard_get_number_columns (pKeyboard);
@@ -214,7 +189,7 @@ gboolean gok_keyslotter_add_prediction_keys (GokKeyboard* pKeyboard, int keytype
 	}
 
 	/* calculate the size of each key */
-	colperkey = maxcols / (keytype == KEYTYPE_WORDCOMPLETE ? numPredictions : numPredictions - 1);
+	colperkey = maxcols / (numPredictions + 1);
 
 	/* add new keys */
 	colleft = 0;
@@ -228,44 +203,35 @@ gboolean gok_keyslotter_add_prediction_keys (GokKeyboard* pKeyboard, int keytype
 		pKeyNew->Left = colleft;
 		pKeyNew->Right = colright;
 		pKeyNew->FontSizeGroup = FONT_SIZE_GROUP_WORDCOMPLETE; /* TODO? */
-		pKeyNew->Type = keytype;
-		pKeyNew->Style = KEYSTYLE_WORDCOMPLETE; /* TODO for command prediction use original keys style.*/
+		pKeyNew->Type = KEYTYPE_WORDCOMPLETE;
+		pKeyNew->Style = KEYSTYLE_WORDCOMPLETE;
 
 		colleft = colright;
 		colright += colperkey;
-						
+
 		pKeyPrevious = pKeyNew;
 	}
-	if (keytype == KEYTYPE_WORDCOMPLETE) 
-	{
-	    /* add an ADDWORD key */
-	    pKeyNew = gok_key_new (pKeyPrevious, NULL, pKeyboard);
-	    
-	    pKeyNew->Top = 0;
-	    pKeyNew->Bottom = 1;
-	    pKeyNew->Left = colleft;
-	    pKeyNew->Right = colright;
-	    pKeyNew->FontSizeGroup = FONT_SIZE_GROUP_UNIQUE;
-	    pKeyNew->Type = KEYTYPE_ADDWORD;
-	    pKeyNew->Style = KEYSTYLE_ADDWORD; 
-	    
-	    colleft = colright;
-	    colright += colperkey;
-	    
-	    pKeyPrevious = pKeyNew;
-	}
+
+	/* add an ADDWORD key */
+	pKeyNew = gok_key_new (pKeyPrevious, pKeyNext, pKeyboard);
+
+	pKeyNew->Top = 0;
+	pKeyNew->Bottom = 1;
+	pKeyNew->Left = colleft;
+	pKeyNew->Right = colright;
+	pKeyNew->FontSizeGroup = FONT_SIZE_GROUP_UNIQUE;
+	pKeyNew->Type = KEYTYPE_ADDWORD;
+	pKeyNew->Style = KEYSTYLE_ADDWORD;
+
+	colleft = colright;
+	colright += colperkey;
+
+	pKeyPrevious = pKeyNew;
 					
 	/* make the prediction keys fill the row */
 	gok_keyboard_fill_row (pKeyboard, 0);
 	
-	if (keytype == KEYTYPE_WORDCOMPLETE)
-	{
-		gok_keyboard_set_wordcomplete_keys_added (pKeyboard, TRUE);
-	}
-	else if (keytype == KEYTYPE_COMMANDPREDICT)
-	{
-		gok_keyboard_set_commandpredict_keys_added (pKeyboard, TRUE);
-	}
+	gok_keyboard_set_wordcomplete_keys_added (pKeyboard, TRUE);
 
 	gok_log_leave();
 	return TRUE;
