@@ -325,6 +325,7 @@ void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 void gok_page_feedbacks_button_clicked_change_name ()
 {
 	GtkWidget* pDialogChangeName;
+	GtkWidget* pContent;
 	GtkWidget* pLabel;
 	GtkWidget* pEntryNewName;
 	gint response;
@@ -341,19 +342,20 @@ void gok_page_feedbacks_button_clicked_change_name ()
 							 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 							 GTK_STOCK_OK, GTK_RESPONSE_OK,
 							 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+	pContent = gtk_dialog_get_content_area (GTK_DIALOG (pDialogChangeName));
 	/* add a text label */
 	pLabel = gtk_label_new (_("Change the feedback name:"));
 	gtk_widget_show (pLabel);
-	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pLabel, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(pContent), pLabel, FALSE, FALSE, 0);
 
 	/* add a text entry */
 	pEntryNewName = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY(pEntryNewName), m_pFeedbackCurrent->pDisplayName);
 	gtk_widget_show (pEntryNewName);
-	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pEntryNewName, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(pContent), pEntryNewName, FALSE, FALSE, 0);
 
 	/* increase the spacing among the controls */
-	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), 10);
+	gtk_box_set_spacing (GTK_BOX(pContent), 10);
 	
 	/* display the dialog */
 	while (1)
