@@ -291,9 +291,9 @@ void gok_settings_page_keysizespace_display_keysizespacing (gint KeyWidth, gint
 
 	/* calculate the left side based upon the window size */
 	pWindowSettings = WID ("window");
-	if (GDK_IS_DRAWABLE(pWindowSettings->window) == TRUE)
+	if (gtk_widget_is_drawable (pWindowSettings))
 	{
-		gdk_drawable_get_size (pWindowSettings->window, &width, NULL);
+		gdk_drawable_get_size (gtk_widget_get_window (pWindowSettings), &width, NULL);
 		left = ((width - 32) - ((KeyWidth * 2) + Space)) / 2;
 	}
 
