@@ -229,7 +229,7 @@ gint closeSwitchApi()
 * 
 *  
 * 
-* returns: Always TRUE to continue watching
+* returns: TRUE to continue watching
 **/ 
 #ifdef __linux__
 static gboolean
@@ -243,7 +243,7 @@ joystick_event (GIOChannel *channel, GIOCondition condition, gpointer data)
 	if (joydata == 0) 
 	{ 
 		gok_log_x ("Warning: Improper callback registration, %u, in joystick_event\n", __LINE__); 
-		return; 
+		return FALSE;
 	} 
  
 	readrc = read (joydata->joystickfd, &js, sizeof(struct js_event)); 
